"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const prometheus = require("prom-client");
const gcStats = require("prometheus-gc-stats");
const AdminPortPlugin_1 = require("../web/AdminPortPlugin");
const LogManager_1 = require("../log/LogManager");
const Logger = LogManager_1.LogManager.getLogger(__filename);
class MetricsPlugin {
    constructor() {
        this.name = 'MetricsPlugin';
    }
    getName() {
        return this.name;
    }
    didStart(app, pluginContext) {
        this.prometheusTimer = prometheus.collectDefaultMetrics();
        prometheus.register.setDefaultLabels({ app: app.getConfig('app.name', 'not_set') });
        const startGcStats = gcStats();
        startGcStats();
        const context = app.getContext();
        const adminExpress = pluginContext.get(AdminPortPlugin_1.default.CONTEXT_APP_KEY);
        if (adminExpress) {
            Logger.info('Registering metrics endpoint in Admin port');
            adminExpress.get('/metrics', async (req, res) => {
                res.type('text/plain');
                res.send(prometheus.register.metrics());
            });
        }
    }
    didStop() {
        prometheus.register.clear();
        if (this.prometheusTimer) {
            Logger.info('Shutting down prometheus interval');
            clearInterval(this.prometheusTimer);
        }
    }
}
exports.default = MetricsPlugin;
//# sourceMappingURL=MetricsPlugin.js.map