"use strict";
// tslint:disable:prefer-function-over-method
Object.defineProperty(exports, "__esModule", { value: true });
const NewrelicUtil_1 = require("../newrelic/NewrelicUtil");
const LogManager_1 = require("../log/LogManager");
const SWAGGER_SECURITY_PROPERTY = 'security';
const newrelic = NewrelicUtil_1.NewrelicUtil.getNewrelicIfAvailable();
const logger = LogManager_1.LogManager.getLogger(__filename);
function assert(predicate, message) {
    if (!predicate) {
        throw new Error(message);
    }
}
class SwaggerAuthenticationMiddleware {
    constructor(context) {
        this.context = context;
        this.handlerCache = new Map();
    }
    needsSecurityCheck(req) {
        logger.debug('needsSecurity ===>');
        logger.debug(req.swagger);
        if (!req || !req.swagger) {
            return false;
        }
        if (req.swagger.operation && req.swagger.operation[SWAGGER_SECURITY_PROPERTY]) {
            return true;
        }
        if (req.swagger.path && req.swagger.path[SWAGGER_SECURITY_PROPERTY]) {
            return true;
        }
        return false;
    }
    /**
     *   "securityDefinitions": {
     *     "Bearer": {
     *       "in": "header",
     *       "type": "apiKey",
     *       "name": "Authorization"
     *     }
     *   }
     */
    geAuthTokenFromHeader(req) {
        const tokenHeader = req.swagger.operation[SWAGGER_SECURITY_PROPERTY]
            ? req.swagger.operation[SWAGGER_SECURITY_PROPERTY]
            : req.swagger.path[SWAGGER_SECURITY_PROPERTY];
    }
    async register(expressApp) {
        expressApp.use(async (req, res, next) => {
            if (newrelic && req.swagger && req.swagger.apiPath) {
                // NR adds a `/` at the start of the path for us.
                const basePath = req.swagger.swaggerObject.basePath.substring(1);
                newrelic.setTransactionName(`${basePath}${req.swagger.apiPath}`);
            }
            try {
                if (this.needsSecurityCheck(req)) {
                    // const handler = await this.getControllerHandler(req);
                    // assert(handler, `Could not find handler for ${getControllerName(req)}#${getOperationName(req)}. Make sure there is a matching class/method registered on the context.`);
                    try {
                        // const resp = await handler(req, res);
                        // assert(res.headersSent, `${getControllerName(req)}#${getOperationName(req)} was called but didn't handle the request. Make sure you always handle the request by calling an appopriate method on "res"`);
                    }
                    catch (error) {
                        next(error); // Send to express error handler
                    }
                }
                else {
                    next(); // Not handled, continue up the middleware chain
                }
            }
            catch (e) {
                next(e); // Send to express error handler
            }
        });
    }
}
exports.default = SwaggerAuthenticationMiddleware;
//# sourceMappingURL=SwaggerAuthenticationMiddleware.js.map